fnss.traffic.trafficmatrices.read_traffic_matrix — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.traffic.trafficmatrices.read_traffic_matrix

`read_traffic_matrix`(path, encoding='utf-8')

  Parses a traffic matrix from a traffic matrix XML file. If the XML file contains more than one traffic matrix, it returns a TrafficMatrixSequence object, otherwise a TrafficMatrixObject.

  Parameters: | path: str : The path of the XML file to parse encoding : str, optional The encoding of the file
  Returns: | tm : TrafficMatrix or TrafficMatrixSequence

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »